---
title: Index of topics
prefix: Search
...

<link rel="stylesheet" href="search.css?v=1">

<input type="search" id="search" placeholder="Search full text" data-url="searchindex.json" data-prefix="../">
<div id="index" data-url="search.json" data-prefix="../"></div>
<script src="../node_modules/lunr/lunr.js"></script>
<script src="search.js?v=a"></script>
